@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from django.utils.translation import ugettext as _
 from django.db import models
 from redactor.fields import RedactorField
@@ -38,7 +39,7 @@ class Page(models.Model):
     content = RedactorField(_('Content'), blank=True)
     template = models.CharField(_('Template name'), max_length=70,
         choices=lazy(pages_templates, tuple)(), blank=True, null=True)
-    menu = models.ForeignKey(Menu, blank=True, null=True)
+    menu = models.ForeignKey(Menu, blank=True, null=True, verbose_name=u'Пункт меню')
 
     def get_absolute_url(self):
         return iri_to_uri(get_script_prefix().rstrip('/') + self.url)
