@@ -3,6 +3,6 @@ from django_zen.views import page
 
 
 urlpatterns = patterns('',
-    url(r'^tinymce/', include('tinymce.urls')),
+    url(r'^redactor/', include('redactor.urls')),
     url(r'^(?P<url>.*)$', page),
 )
